/*
 * This file is part of AV Orchid.
 * Copyright (c) 2013, Dmitri R. Kuvshinov <evetro.here@gmail.com>
 * 
 * Permission to use, copy, modify, and/or distribute this software for
 * any purpose with or without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all copies.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/**
 * @file   Timer.cpp
 * @brief  Timer.hpp implementation
 * @author Dmitri Kuvshinov
 */
#include <avo/Timer.hpp>

#include <chrono>
#include <thread>

namespace
{
  const auto starting_time = std::chrono::high_resolution_clock::now();
}

double avo::seconds()
{
  using namespace std::chrono;
  return (duration_cast<nanoseconds>(high_resolution_clock::now() - starting_time)).count() * 1.0e-9;
}

double avo::timer_ticks()
{
  return 1.0e+9; // pseudoticks, nanoseconds
}

void avo::sleep(double t)
{
  std::this_thread::sleep_for(std::chrono::milliseconds(static_cast<int>(1000.0 * t)));
}
