﻿/*
 * This file is part of AV Orchid.
 * Copyright (c) 2013, Dmitri R. Kuvshinov <evetro.here@gmail.com>
 * 
 * Permission to use, copy, modify, and/or distribute this software for
 * any purpose with or without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all copies.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/**
 * @file EnterNameScreen.hpp
 *
 * Экран ввода имени игрока (для отображения в списке лучших, если, конечно, он туда попадёт).
 */
#pragma once
#include "DemoGameScreen.hpp"
#include <string>

/// класс, реализующий экран ввода имени игрока
class EnterNameScreen: public DemoGameScreen
{
public:

  /// внешний обработчик события "имя введено"
  typedef std::function<void(const std::string&)> NameEnteredHandler;
  /// привязать обработчик события "имя введено"
  void setNameEnteredHandler(NameEnteredHandler handler)
  {
    doTransmitName = handler;
  }

  /// выставить текущие очки (передаётся уже готовое строковое представление)
  void setScore(const std::string &sc)
  {
    name.clear();
    score = sc;
  }

protected:

  void onDisplay() override;
  void onChar(unsigned char code, int, int) override;

private:

  typedef DemoGameScreen Base;
  NameEnteredHandler doTransmitName;
  std::string name, score;
};
